@@ -337,7 +337,8 @@ void    smtpd_peer_init(SMTPD_STATE *state)
 	     * must not be allowed to enter the audit trail, as people would
 	     * draw false conclusions.
 	     */
-	    aierr = hostname_to_sockaddr(state->name, (char *) 0, 0, &res0);
+	    aierr = hostname_to_sockaddr_pf(state->name, state->addr_family,
+					    (char *) 0, 0, &res0);
 	    if (aierr) {
 		msg_warn("%s: hostname %s verification failed: %s",
 			 state->addr, state->name, MAI_STRERROR(aierr));
